@@ -39,9 +39,6 @@ class RallyCliError(Exception):
     def __str__(self):
         return self.msg
 
-    def __unicode__(self):
-        return self.msg
-
 
 class JsonTempFile(object):
 
@@ -74,9 +71,10 @@ class Rally(object):
 
     def __init__(self, force_new_db=False, plugin_path=None, config_opts=None):
         if not os.path.exists(self.ENV_FILE):
-            subprocess.call(["rally", "--log-file", "/dev/null",
-                             "env", "show", "--only-spec"],
-                            stdout=open(self.ENV_FILE, "w"))
+            with open(self.ENV_FILE, "w") as f:
+                subprocess.call(["rally", "--log-file", "/dev/null",
+                                 "env", "show", "--only-spec"],
+                                stdout=f)
         with open(self.ENV_FILE) as f:
             self.env_spec = json.loads(f.read())
             print(self.env_spec)
@@ -203,9 +201,10 @@ class Rally(object):
         try:
             if no_logs or getjson:
                 cmd = self.args + ["--log-file", "/dev/null"] + cmd
-                with open(os.devnull, "w") as DEVNULL:
-                    output = encodeutils.safe_decode(subprocess.check_output(
-                        cmd, stderr=DEVNULL, env=self.env))
+                output = encodeutils.safe_decode(
+                    subprocess.check_output(
+                        cmd, stderr=subprocess.DEVNULL, env=self.env)
+                )
             else:
                 cmd = self.args + cmd
                 output = encodeutils.safe_decode(subprocess.check_output(
